local imgui = require('imgui')
local encoding = require 'encoding'
encoding.default = 'CP1251'
u8 = encoding.UTF8
local sampev = require 'lib.samp.events'

local window = imgui.ImBool(false)
local add_objectid = imgui.ImInt(10)
local renderObjectInfo = imgui.ImBool(false)

local list = {}
local file = {dir = getWorkingDirectory()..'\\resource', name = 'BlacklistedObjects.txt'}

local font = renderCreateFont('Arial', 10, 5)

function sampev.onSendCommand(text)
    if text:lower() == '/blo'--[[text:lower():find('/blm') or text:lower():find('/george_floyd')]] then
        window.v = not window.v
        return false
    end
end

function main()
    while not isSampAvailable() do wait(200) end
    if not doesFileExist(file.dir..'\\'..file.name) then saveList() end
    loadList()
    imgui.Process = false
    window.v = false  --show window
    while true do
        wait(0)
        imgui.Process = window.v
        if renderObjectInfo.v then
            for k, v in ipairs(getAllObjects()) do
                x, y, z = getCharCoordinates(PLAYER_PED)
                result, ox, oy, oz = getObjectCoordinates(v)
                if result then
                    if getDistanceBetweenCoords3d(x, y, z, ox, oy, oz) <= 10 then
                        rX, rY = convert3DCoordsToScreen(ox, oy, oz)
                        renderFontDrawText(font, '{ff004d}Object ID: {ffffff}'..getObjectModel(v), rX, rY, 0xFFFFFFFF, 0x90000000)
                    end
                end
            end
        end
    end
end

function imgui.OnDrawFrame()
    if window.v then
        resX, resY = getScreenResolution()
        local defSize = {x = 300, y = 300}
        imgui.SetNextWindowPos(imgui.ImVec2(resX / 2 - defSize.x / 2, resY / 2 - defSize.y / 2), imgui.Cond.FirstUseEver)
        imgui.SetNextWindowSize(imgui.ImVec2(defSize.x, defSize.y), imgui.Cond.FirstUseEver)
        imgui.Begin('Blacklisted Objects', window)

        winSize = imgui.GetWindowSize()
        imgui.SetCursorPosX(5)
        if imgui.Button(u8' ', imgui.ImVec2(winSize.x - 10, 20)) then
            imgui.OpenPopup(u8' ')
        end
        imgui.Checkbox(u8' ID  ', renderObjectInfo)
        if imgui.IsItemHovered() then
            imgui.BeginTooltip()
                imgui.Text(u8'   , \n       ID\n(       10   )')
            imgui.EndTooltip()
        end
        imgui.Separator()

        if imgui.BeginPopupModal(u8' ', true, imgui.WindowFlags.NoTitleBar + imgui.WindowFlags.NoResize) then
            imgui.SetWindowSize(imgui.ImVec2(210, 100))
            imgui.Text(u8'ID : ')
            imgui.SameLine()
            imgui.PushItemWidth(120)
            imgui.InputInt('##ADD_INPUT_OBJECT_ID', add_objectid)
            imgui.PopItemWidth()
            imgui.SetCursorPos(imgui.ImVec2(5, 50))
            if imgui.Button(u8'', imgui.ImVec2(200, 20)) then 
                if string.len(add_objectid.v) > 0 then 
                    table.insert(list, tonumber(add_objectid.v))
                else
                    sampAddChatMessage('   ,      id!', -1)
                end
                saveList()
                imgui.CloseCurrentPopup()
            end

            imgui.SetCursorPos(imgui.ImVec2(5, 75))
            if imgui.Button(u8'', imgui.ImVec2(200, 20)) then imgui.CloseCurrentPopup() end
            imgui.EndPopup()
        end

        if list[1] ~= nil then
            for i = 1, #list do
                imgui.Text('ID: '..tostring(list[i]))
                imgui.SameLine()
                imgui.SetCursorPosX(winSize.x - 5 - 60)
                
                if imgui.Button(u8'##'..tostring(i), imgui.ImVec2(60, 18)) then table.remove(list, i) end
                imgui.Separator()
            end
        else
            imgui.Text(u8'  :(')
        end

        imgui.End()
    end
end

function sampev.onCreateObject(objectId, data) 
    if list[1] ~= nil then
        for i = 1, #list do
            if data.modelId == list[i] then return false end
        end
    end
end

--      json

function loadList()
    local file = file.dir..'\\'..file.name
    for line in io.lines(file) do 
        table.insert(list, tonumber(line))
    end    
end

function saveList()
    wtext = ''
    if list[1] ~= nil then
        for i = 1, #list do
            wtext = list[i]..'\n'..wtext..'\n'
        end
    end
    config = io.open(file.dir..'\\'..file.name, 'w')
    config:write(wtext)
    config:close()
end

function applyTheme()
    imgui.SwitchContext()
    local style = imgui.GetStyle()
    local colors = style.Colors
    local clr = imgui.Col
    local ImVec4 = imgui.ImVec4
    local ImVec2 = imgui.ImVec2
  
  
    style.WindowPadding = ImVec2(6, 4)
    style.WindowRounding = 5.0
    style.FramePadding = ImVec2(3, 3)
    style.FrameRounding = 5.0
    style.ItemSpacing = ImVec2(5, 3)
    style.ItemInnerSpacing = ImVec2(3, 3)
    style.TouchExtraPadding = ImVec2(10, 10)
    style.IndentSpacing = 6.0
    style.ScrollbarSize = 12.0
    style.ScrollbarRounding = 5.0
    style.GrabMinSize = 20.0
    style.GrabRounding = 2.0
  
    style.WindowTitleAlign = ImVec2(0.5, 0.5)

    
    colors[clr.Border] = ImVec4(1, 0, 0.3, 1.00)
    colors[clr.WindowBg] = ImVec4(0.13, 0.14, 0.17, 1.00)
    colors[clr.FrameBg] = ImVec4(0.200, 0.220, 0.270, 0.85)
    colors[clr.TitleBg] = ImVec4(1, 0, 0.3, 1.00)
    colors[clr.TitleBgActive] = ImVec4(1, 0, 0.3, 1.00)
    colors[clr.Button] = ImVec4(1, 0, 0.3, 1.00)
    colors[clr.ButtonHovered] = ImVec4(1, 0, 0.3, 1.00)
    colors[clr.Separator] = ImVec4(1, 0, 0.3, 1.00)
    --CollapsingHeader
    colors[clr.Header] = ImVec4(1, 0, 0.3, 1.00)
    colors[clr.HeaderHovered] = ImVec4(0.68, 0, 0.2, 0.86)
    colors[clr.HeaderActive] = ImVec4(1, 0.24, 0.47, 1.00)
    colors[clr.CheckMark] = ImVec4(1, 0, 0.3, 1.00)
    colors[clr.ModalWindowDarkening] = ImVec4(0.200, 0.220, 0.270, 0.73)

    colors[clr.ScrollbarBg] = ImVec4(0.200, 0.220, 0.270, 0.85)
    colors[clr.ScrollbarGrab] = ImVec4(1, 0, 0.3, 1.00)
    colors[clr.ScrollbarGrabHovered] = ImVec4(1, 0, 0.3, 1.00)
    colors[clr.ScrollbarGrabActive] = ImVec4(1, 0, 0.3, 1.00)

    colors[clr.ButtonActive] = ImVec4(1, 0, 0.3, 1.00)
    
end
applyTheme()